import { AxisPlacement, ScaleDistribution } from '@grafana/schema';
import { FIXED_UNIT } from './types.js';

function buildScaleKey(config, fieldType) {
  var _a, _b, _c, _d, _e, _f, _g;
  const defaultPart = "na";
  const scaleRange = `${config.min !== undefined ? config.min : defaultPart}-${config.max !== undefined ? config.max : defaultPart}`;
  const scaleSoftRange = `${((_a = config.custom) == null ? undefined : _a.axisSoftMin) !== undefined ? config.custom.axisSoftMin : defaultPart}-${((_b = config.custom) == null ? undefined : _b.axisSoftMax) !== undefined ? config.custom.axisSoftMax : defaultPart}`;
  const scalePlacement = `${((_c = config.custom) == null ? undefined : _c.axisPlacement) !== undefined ? (_d = config.custom) == null ? undefined : _d.axisPlacement : AxisPlacement.Auto}`;
  const scaleUnit = (_e = config.unit) != null ? _e : FIXED_UNIT;
  const scaleDistribution = ((_f = config.custom) == null ? undefined : _f.scaleDistribution) ? getScaleDistributionPart(config.custom.scaleDistribution) : ScaleDistribution.Linear;
  const scaleLabel = Boolean((_g = config.custom) == null ? undefined : _g.axisLabel) ? config.custom.axisLabel : defaultPart;
  return `${scaleUnit}/${scaleRange}/${scaleSoftRange}/${scalePlacement}/${scaleDistribution}/${scaleLabel}/${fieldType}`;
}
function getScaleDistributionPart(config) {
  if (config.type === ScaleDistribution.Log) {
    return `${config.type}${config.log}`;
  }
  return config.type;
}

export { buildScaleKey };
//# sourceMappingURL=internal.js.map
